@@ -1,7 +1,7 @@
 use std::mem::MaybeUninit;
 use std::ops::Range;
 
-use super::RealFrames;
+use super::Frames;
 
 /// An audio buffer with a single channel.
 ///
@@ -45,7 +45,7 @@ impl<T: Default + Copy + Clone, const MAX_BLOCKSIZE: usize> MonoBlockBuffer<T, M
     /// ## Undefined behavior
     /// The portion of data not in the given range will be unitialized, so undefined behavior
     /// may occur if you try to read any of that data without writing to it first.
-    pub unsafe fn new_uninit_after_frames(frames: RealFrames) -> Self {
+    pub unsafe fn new_uninit_after_frames(frames: Frames) -> Self {
         let frames = frames.0.min(MAX_BLOCKSIZE);
         let mut buf: [T; MAX_BLOCKSIZE] = MaybeUninit::uninit().assume_init();
 
@@ -82,7 +82,7 @@ impl<T: Default + Copy + Clone, const MAX_BLOCKSIZE: usize> MonoBlockBuffer<T, M
 
     /// Clear a number of frames in the buffer to 0.
     #[inline]
-    pub fn clear_frames(&mut self, frames: RealFrames) {
+    pub fn clear_frames(&mut self, frames: Frames) {
         let frames = frames.0.min(MAX_BLOCKSIZE);
         let buf_part = &mut self.buf[0..frames];
         buf_part.fill(T::default());
@@ -106,11 +106,7 @@ impl<T: Default + Copy + Clone, const MAX_BLOCKSIZE: usize> MonoBlockBuffer<T, M
 
     /// Copy the given number of `frames` from `src` to this buffer.
     #[inline]
-    pub fn copy_frames_from(
-        &mut self,
-        src: &MonoBlockBuffer<T, MAX_BLOCKSIZE>,
-        frames: RealFrames,
-    ) {
+    pub fn copy_frames_from(&mut self, src: &MonoBlockBuffer<T, MAX_BLOCKSIZE>, frames: Frames) {
         let frames = frames.0.min(MAX_BLOCKSIZE);
         self.buf[0..frames].copy_from_slice(&src.buf[0..frames]);
     }
@@ -185,7 +181,7 @@ impl<T: Default + Copy + Clone, const MAX_BLOCKSIZE: usize> StereoBlockBuffer<T,
     /// ## Undefined behavior
     /// The portion of data not in the given range will be unitialized, so undefined behavior
     /// may occur if you try to read any of that data without writing to it first.
-    pub unsafe fn new_uninit_after_frames(frames: RealFrames) -> Self {
+    pub unsafe fn new_uninit_after_frames(frames: Frames) -> Self {
         let frames = frames.0.min(MAX_BLOCKSIZE);
         let mut buf_left: [T; MAX_BLOCKSIZE] = MaybeUninit::uninit().assume_init();
         let mut buf_right: [T; MAX_BLOCKSIZE] = MaybeUninit::uninit().assume_init();
@@ -235,7 +231,7 @@ impl<T: Default + Copy + Clone, const MAX_BLOCKSIZE: usize> StereoBlockBuffer<T,
 
     /// Clear a number of frames in the buffer to 0.
     #[inline]
-    pub fn clear_frames(&mut self, frames: RealFrames) {
+    pub fn clear_frames(&mut self, frames: Frames) {
         let frames = frames.0.min(MAX_BLOCKSIZE);
         let buf_left_part = &mut self.left[0..frames];
         let buf_right_part = &mut self.right[0..frames];
@@ -264,11 +260,7 @@ impl<T: Default + Copy + Clone, const MAX_BLOCKSIZE: usize> StereoBlockBuffer<T,
 
     /// Copy the given number of `frames` from `src` to this buffer.
     #[inline]
-    pub fn copy_frames_from(
-        &mut self,
-        src: &StereoBlockBuffer<T, MAX_BLOCKSIZE>,
-        frames: RealFrames,
-    ) {
+    pub fn copy_frames_from(&mut self, src: &StereoBlockBuffer<T, MAX_BLOCKSIZE>, frames: Frames) {
         let frames = frames.0.min(MAX_BLOCKSIZE);
         self.left[0..frames].copy_from_slice(&src.left[0..frames]);
         self.right[0..frames].copy_from_slice(&src.right[0..frames]);
