@@ -1,4 +1,4 @@
-use super::{RealFrames, RealSampleTime, SampleRate, Seconds};
+use super::{Frames, SampleRate, SampleTime, Seconds};
 
 pub static U24_TO_F32_RATIO: f32 = 2.0 / 0x00FFFFFF as f32;
 pub static I16_TO_F32_RATIO: f32 = 1.0 / std::i16::MAX as f32;
@@ -22,7 +22,7 @@ impl AnyPCM {
     }
 
     /// The length (of a single de-interleaved channel) of this resource in real samples.
-    pub fn len(&self) -> RealFrames {
+    pub fn len(&self) -> Frames {
         match self {
             AnyPCM::Mono(pcm) => pcm.len(),
             AnyPCM::Stereo(pcm) => pcm.len(),
@@ -54,7 +54,7 @@ impl MonoPCM {
     }
 
     pub fn new(data: Vec<f32>, sample_rate: SampleRate) -> Self {
-        let len_secs = RealSampleTime(data.len() as i64).to_seconds(sample_rate);
+        let len_secs = SampleTime(data.len() as i64).to_seconds(sample_rate);
 
         Self {
             data,
@@ -76,21 +76,21 @@ impl MonoPCM {
     pub fn set_sample_rate(&mut self, sample_rate: SampleRate) {
         if self.sample_rate != sample_rate {
             self.sample_rate = sample_rate;
-            self.len_secs = RealSampleTime(self.data.len() as i64).to_seconds(sample_rate);
+            self.len_secs = SampleTime(self.data.len() as i64).to_seconds(sample_rate);
         }
     }
 
-    pub fn resize(&mut self, new_len: RealFrames, value: f32) {
+    pub fn resize(&mut self, new_len: Frames, value: f32) {
         if self.data.len() != new_len.0 {
             self.data.resize(new_len.0, value);
-            self.len_secs = RealSampleTime(self.data.len() as i64).to_seconds(self.sample_rate);
+            self.len_secs = SampleTime(self.data.len() as i64).to_seconds(self.sample_rate);
         }
     }
 
-    pub unsafe fn set_len(&mut self, new_len: RealFrames) {
+    pub unsafe fn set_len(&mut self, new_len: Frames) {
         if self.data.len() != new_len.0 {
             self.data.set_len(new_len.0);
-            self.len_secs = RealSampleTime(self.data.len() as i64).to_seconds(self.sample_rate);
+            self.len_secs = SampleTime(self.data.len() as i64).to_seconds(self.sample_rate);
         }
     }
 
@@ -106,7 +106,7 @@ impl MonoPCM {
 
     /// The length of this resource in real samples.
     #[inline]
-    pub fn len(&self) -> RealFrames {
+    pub fn len(&self) -> Frames {
         self.data.len().into()
     }
 
@@ -138,7 +138,7 @@ impl StereoPCM {
     pub fn new(left: Vec<f32>, right: Vec<f32>, sample_rate: SampleRate) -> Self {
         assert_eq!(left.len(), right.len());
 
-        let len_secs = RealSampleTime(left.len() as i64).to_seconds(sample_rate);
+        let len_secs = SampleTime(left.len() as i64).to_seconds(sample_rate);
 
         Self {
             left,
@@ -166,23 +166,23 @@ impl StereoPCM {
     pub fn set_sample_rate(&mut self, sample_rate: SampleRate) {
         if self.sample_rate != sample_rate {
             self.sample_rate = sample_rate;
-            self.len_secs = RealSampleTime(self.left.len() as i64).to_seconds(sample_rate);
+            self.len_secs = SampleTime(self.left.len() as i64).to_seconds(sample_rate);
         }
     }
 
-    pub fn resize(&mut self, new_len: RealFrames, value: f32) {
+    pub fn resize(&mut self, new_len: Frames, value: f32) {
         if self.left.len() != new_len.0 {
             self.left.resize(new_len.0, value);
             self.right.resize(new_len.0, value);
-            self.len_secs = RealSampleTime(self.left.len() as i64).to_seconds(self.sample_rate);
+            self.len_secs = SampleTime(self.left.len() as i64).to_seconds(self.sample_rate);
         }
     }
 
-    pub unsafe fn set_len(&mut self, new_len: RealFrames) {
+    pub unsafe fn set_len(&mut self, new_len: Frames) {
         if self.left.len() != new_len.0 {
             self.left.set_len(new_len.0);
             self.right.set_len(new_len.0);
-            self.len_secs = RealSampleTime(self.left.len() as i64).to_seconds(self.sample_rate);
+            self.len_secs = SampleTime(self.left.len() as i64).to_seconds(self.sample_rate);
         }
     }
 
@@ -194,7 +194,7 @@ impl StereoPCM {
 
     /// The length (of a single de-interleaved channel) of this resource in real samples.
     #[inline]
-    pub fn len(&self) -> RealFrames {
+    pub fn len(&self) -> Frames {
         self.left.len().into()
     }
 
